PinnDE
--------

Physics Informed Neural Networks for Differential Equations (PinnDE) is an open-source library
in Python 3 for solving ordinary and partial differential equations (ODEs and PDEs) using both
physics informed neural networks (PINNs) and deep operator networks (DeepONets). The goal of PinnDE is to
provide a user-friendly library as an alternative to the more powerful but more complex alternatives. This library provides
simple, user-friendly interfacing of solving methods which can easily be used in collaboration with 
non-profficent users of python or the library, where collaborators should be able to understand the contents of
the code quickly and without having to learn the library themselves.